import React, { useEffect } from 'react';
import ReactJSONView from 'react-json-view';
import { VisualizationPropTypes, VISComponentType, VisualizationSettingsPropTypes } from '../../common';
import { SettingsContainer } from '@graphpolaris/shared/lib/vis/components/config';
import { Input } from '@graphpolaris/shared/lib/components/inputs';

export interface RawJSONVisProps {
  theme: string;
  iconStyle: 'circle' | 'triangle' | 'square' | undefined;
}

const settings: RawJSONVisProps = {
  theme: 'bright:inverted',
  iconStyle: 'circle',
};

export const RawJSONVis = React.memo(({ data, settings }: VisualizationPropTypes) => {
  return (
    <ReactJSONView
      src={data}
      collapsed={1}
      quotesOnKeys={false}
      style={{ padding: '20px', flexGrow: 1 }}
      theme={settings.theme || 'bright:inverted'}
      iconStyle={settings.iconStyle}
      enableClipboard={true}
    />
  );
});

const RawJSONSettings = ({ settings, updateSettings }: VisualizationSettingsPropTypes<RawJSONVisProps>) => {
  return (
    <SettingsContainer>
      <Input
        type="dropdown"
        label="Select a theme"
        value={settings.theme}
        options={['bright:inverted', 'monokai', 'ocean']}
        onChange={(val) => updateSettings({ theme: val as any })}
      />
      <Input
        type="dropdown"
        label="Icon style"
        value={settings.iconStyle}
        options={['circle', 'square', 'triangle']}
        onChange={(val) => updateSettings({ iconStyle: val as any })}
      />
    </SettingsContainer>
  );
};

export const RawJSONComponent: VISComponentType<RawJSONVisProps> = {
  displayName: 'RawJSONVis',
  component: RawJSONVis,
  settingsComponent: RawJSONSettings,
  settings: settings,
};
export default RawJSONComponent;
